@@ -1,17 +1,19 @@
 package Test::File;
 use strict;
 
-use base qw(Exporter);
 use vars qw(@EXPORT $VERSION);
 
+use Carp            qw(carp);
+use Exporter        qw(import);
 use File::Spec;
 use Test::Builder;
 
 @EXPORT = qw(
 	file_exists_ok file_not_exists_ok
 	file_empty_ok file_not_empty_ok file_size_ok file_max_size_ok
-	file_min_size_ok file_readable_ok file_not_readable_ok file_writeable_ok
-	file_not_writeable_ok file_executable_ok file_not_executable_ok
+	file_min_size_ok file_readable_ok file_not_readable_ok
+	file_writeable_ok file_writable_ok file_not_writeable_ok file_not_writable_ok
+	file_executable_ok file_not_executable_ok
 	file_mode_is file_mode_isnt
 	file_mode_has file_mode_hasnt
 	file_is_symlink_ok
@@ -28,7 +30,7 @@ use Test::Builder;
 	file_mtime_gt_ok file_mtime_lt_ok file_mtime_age_ok
 	);
 
-$VERSION = '1.441_01';
+$VERSION = '1.443_01';
 
 {
 use warnings;
@@ -740,17 +742,29 @@ sub file_not_readable_ok
 		}
 	}
 
+=item file_writable_ok( FILENAME [, NAME ] )
+
 =item file_writeable_ok( FILENAME [, NAME ] )
 
-Ok if the file exists and is writeable, not ok
-if the file does not exist or is not writeable.
+Ok if the file exists and is writable, not ok if the file does not
+exist or is not writable.
+
+The original name is C<file_writeable_ok> with that extra I<e>. That
+still works but there's a function with the correct spelling too.
 
 =cut
 
 sub file_writeable_ok
+	{
+	carp "file_writeable_ok is now file_writable_ok";
+
+	&file_writable_ok;
+	}
+
+sub file_writable_ok
 	{
 	my $filename = _normalize( shift );
-	my $name     = shift || "$filename is writeable";
+	my $name     = shift || "$filename is writable";
 
 	my $ok = -w $filename;
 
@@ -760,22 +774,34 @@ sub file_writeable_ok
 		}
 	else
 		{
-		$Test->diag( "File [$filename] is not writeable!" );
+		$Test->diag( "File [$filename] is not writable!" );
 		$Test->ok(0, $name);
 		}
 	}
 
 =item file_not_writeable_ok( FILENAME [, NAME ] )
 
-Ok if the file exists and is not writeable, not ok
-if the file does not exist or is writeable.
+=item file_not_writable_ok( FILENAME [, NAME ] )
+
+Ok if the file exists and is not writable, not ok if the file does not
+exist or is writable.
+
+The original name is C<file_not_writeable_ok> with that extra I<e>.
+That still works but there's a function with the correct spelling too.
 
 =cut
 
 sub file_not_writeable_ok
+	{
+	carp "file_not_writeable_ok is now file_not_writable_ok";
+
+	&file_not_writable_ok;
+	}
+
+sub file_not_writable_ok
 	{
 	my $filename = _normalize( shift );
-	my $name     = shift || "$filename is not writeable";
+	my $name     = shift || "$filename is not writable";
 
 	my $ok = not -w $filename;
 
@@ -785,7 +811,7 @@ sub file_not_writeable_ok
 		}
 	else
 		{
-		$Test->diag("File [$filename] is writeable!");
+		$Test->diag("File [$filename] is writable!");
 		$Test->ok(0, $name);
 		}
 	}
@@ -1655,7 +1681,7 @@ sub file_mtime_gt_ok
 	{
 	my $filename    = shift;
 	my $time        = int shift;
-	my $name        = shift || "$filename mtime is less than unix timestamp $time";
+	my $name        = shift || "$filename mtime is greater than unix timestamp $time";
 
 	my $filetime = _stat_file($filename, 9);
 
@@ -1665,7 +1691,7 @@ sub file_mtime_gt_ok
 
 	$Test->diag( "Filename [$filename] mtime [$filetime] not greater than $time" );
 	$Test->ok(0, $name);
-  }
+	}
 
 =item file_mtime_lt_ok( FILE, UNIXTIME, [, NAME ] )
 
@@ -1775,9 +1801,10 @@ C<file_contains_unlike>.
 xmikew C<< <https://github.com/xmikew> >> provided the C<mtime_age>
 stuff.
 
+
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2002-2015, brian d foy <bdfoy@cpan.org>. All rights reserved.
+Copyright © 2002-2020, brian d foy <bdfoy@cpan.org>. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
